# Data

**icsd_filtered_info_2024_vX.json.gz**: Dict. key = chemical system, value = list of ICSD
  data containing tuples: (reduced_formula, icsd_id, spacegroup, e_above_hull). This
  file is generated by the filter_icsd.py script and is used to prioritize structures
  used in DARA. Duplicate structures are removed, and only the oldest ICSD entry closest
  to room temperature is kept. Energies above hull are determined by looking for matches
  with the same spacegroup and formula on Materials Project; hence they are only rough
  estimates for prioritization.
